@@ -161,7 +161,7 @@ def map_pssms(pdb_filename, blastdb, output_filename):
 
 def _psaia(psaia_config_file, file_list_file):
     """Run PSAIA on specified input."""
-    psaia_command = "psa {:} {:}"  # PSA is the CLI for PSAIA (the GUI)
+    psaia_command = "yes y | psa {:} {:}"  # PSA is the CLI for PSAIA (the GUI)
     log_out = "{}.out".format(file_list_file)
     log_err = "{}.err".format(file_list_file)
     with open(log_out, 'a') as f_out:
@@ -226,7 +226,7 @@ def map_all_protrusion_indices(psaia_config_file, pdb_dataset, output_dir, sourc
             file.write(f'{requested_pdb_filename}\n')
 
     logging.info("{:} PDB files to process with PSAIA".format(len(requested_pdb_filenames)))
-    inputs = [(psaia_config_file, file_list) for file_list in zip(psaia_config_file, file_list_file)]
+    inputs = [(psaia_config_file, file_list_file)]
     par.submit_jobs(map_protrusion_indices, inputs, 1)  # PSAIA is inherently single-threaded in execution
 
 
